# the Algmon Body lib

## company intro

* https://algmon.com/

## **toolkit intro**

* https://algmon.com/docs/infra/intro

## main features

* 3D & 4D ... time & space modeling
* sequence motion simulation
* static & dynamic interaction

## dependencies

* python package
* 

## how to clean & publish

1. (optional) python setup.py clean --all
2. python -m build
3. (optional) twine upload -r testpypi dist/*
4. twine upload dist/*

## how to INSTALL

## how to TEST

## how to USE

## the license

* This package is released under the Apache License v2
